working=/users/rg/buszczynska/Projects/polonez/ercc

cd $working

# -------------------------------------------------------
# get the ercc sequences 
# -------------------------------------------------------

# get metadata
wget https://assets.thermofisher.com/TFS-Assets/LSG/manuals/cms_095046.txt -O ercc.metadata.tsv

# get fasta
wget https://assets.thermofisher.com/TFS-Assets/LSG/manuals/ERCC92.zip .
unzip ERCC92.zip

# fasta2tbl
FastaToTbl ERCC92.fa| awk 'BEGIN{OFS="\t"}{print $1, $2}' > ercc.seq.tsv

# get subgroups
cat ercc.metadata.tsv| grep -v Re-sort| awk 'BEGIN{OFS="\t"}{print $2, $3}' > ercc.group.tsv

# join
join.py -b ercc.group.tsv -a ercc.seq.tsv -x 1 -y 1 > ercc.input.tsv

# -------------------------------------------------------
# length 
# -------------------------------------------------------

while read ercc gr sequ
do
    len=`echo $sequ| wc -m`
    echo -e "$ercc\t$len\t$gr\tAll"
done < ercc.input.tsv > ercc.length.tsv

# All
echo "
library(ggplot2)
library(scales)
cbPalette <- c(\"#5b58c4\")
plot <- read.table('ercc.length.tsv', header=F, as.is=T, sep=\"\t\")
colnames(plot)<-c(\"ercc\",\"count\",\"group\", \"typ\")
label=matrix(0,1,3) 
median=median(plot[, 2])
len=length(plot[, 2])
t=paste(\"N =\", prettyNum(len,big.mark=\",\",scientific=FALSE), \"\nMedian =\", prettyNum(round(median,2),big.mark=\",\",scientific=FALSE))
label[1,1]=\"E\"
label[1,2]=\"All\"
label[1,3]=t
label=as.data.frame(label)
row.names(label)=NULL
colnames(label)=c('group', 'typ', 'text')
png(\"ercc.length.png\", bg = \"white\", units=\"in\", width=6.5, height=6, res=300)
ggplot(plot, aes(x=count, color=typ)) + geom_density(size=2) + scale_color_manual(values=cbPalette)+ylim(0,0.0015) + xlab(\"Length of ERCC spike-ins (nt)\") + ylab (\"Density\")+ theme_bw()+theme(axis.text.x = element_text(size = 16, colour = \"black\"), axis.text.y = element_text(size = 16,  colour = \"black\"), legend.text = element_text(size=14), plot.title = element_text(size = 22), legend.title =element_text(size=0, color=\"white\"), axis.title.x = element_text(size = 18), axis.title.y = element_text(size = 18), legend.text.align=0.5, strip.text.x=element_text(size=18), strip.text.y=element_text(size=18))+ ggtitle('')+theme(legend.position=\"none\")+facet_wrap(~typ)+ geom_text(data=label, aes(x=1600, y=0.0013, label=text), size=5, color=\"black\")
dev.off()
" | R --slave

cp ercc.length.png /users/rg/buszczynska/public_html/gencode/tmp/B/COT/ercc

# per group
echo "
library(ggplot2)
library(scales)
plot <- read.table('ercc.length.tsv', header=F, as.is=T, sep=\"\t\")
colnames(plot)<-c(\"ercc\",\"count\",\"group\", \"typ\")
list=c(\"A\",\"B\", \"C\", \"D\")
label=matrix(0,length(list),3) 
for (i in 1:length(list))
{
median=median(plot[plot\$group==list[i], 2])
len=length(plot[plot\$group==list[i], 2])
t=paste(\"N =\", prettyNum(len,big.mark=\",\",scientific=FALSE), \"\nMedian =\", prettyNum(round(median,2),big.mark=\",\",scientific=FALSE))
label[i,1]=list[i]
label[i,2]=\"All\"
label[i,3]=t
}

label=as.data.frame(label)
row.names(label)=NULL
colnames(label)=c('group', 'typ', 'text')
png(\"ercc.length.pergr.png\", bg = \"white\", units=\"in\", width=8, height=6, res=300)
ggplot(plot, aes(x=count, color=group)) + geom_density(size=2) + scale_color_brewer(palette=\"Dark2\") +ylim(0,0.0015)+ xlab(\"Length of ERCC spike-ins (nt)\") + ylab (\"Density\")+ theme_bw()+theme(axis.text.x = element_text(size = 16, colour = \"black\"), axis.text.y = element_text(size = 16,  colour = \"black\"), legend.text = element_text(size=14), plot.title = element_text(size = 22), legend.title =element_text(size=0, color=\"white\"), axis.title.x = element_text(size = 18), axis.title.y = element_text(size = 18), legend.text.align=0.5, strip.text.x=element_text(size=18), strip.text.y=element_text(size=18))+ ggtitle('')+theme(legend.position=\"none\")+facet_wrap(~group)+ geom_text(data=label, aes(x=1600, y=0.0013, label=text), size=5, color=\"black\")
dev.off()
" | R --slave

cp ercc.length.pergr.png /users/rg/buszczynska/public_html/gencode/tmp/B/COT/ercc

# -------------------------------------------------------
# trim polyA
# -------------------------------------------------------

# trimm polyA
~/.local/bin/cutadapt -a "A{100}" -o ERCC92.polyAtrimm.fa ERCC92.fa

# fasta2tbl
FastaToTbl ERCC92.polyAtrimm.fa| awk 'BEGIN{OFS="\t"}{print $1, $2}' > ercc.seq.polyAtrimm.tsv

# join
join.py -b ercc.group.tsv -a ercc.seq.polyAtrimm.tsv -x 1 -y 1 > ercc.input.polyAtrimm.tsv

# -------------------------------------------------------
# get GC content
# -------------------------------------------------------

./gccontent.pl ERCC92.polyAtrimm.fa > ercc.polyAtrimm.gc.tsv

# join
join.py -b ercc.group.tsv -a ercc.polyAtrimm.gc.tsv -x 1 -y 1 > ercc.input.polyAtrimm.gc.tsv

# order spike-ins
cat ercc.input.polyAtrimm.gc.tsv| cut -f1 > ercc.input.polyAtrimm.gc.order 

cat ercc.input.polyAtrimm.gc.tsv| awk 'BEGIN{FS=OFS="\t"}{print $1, $2, $3, "All"}' > ercc.input.polyAtrimm.gc.all.tsv

# All
echo "
library(ggplot2)
library(scales)
cbPalette <- c(\"#5b58c4\")
plot <- read.table('ercc.input.polyAtrimm.gc.all.tsv', header=F, as.is=T, sep=\"\t\")
ord <- read.table('ercc.input.polyAtrimm.gc.order', header=F, as.is=T, sep=\"\t\")
colnames(plot)<-c(\"ercc\",\"group\",\"count\", \"typ\")
plot\$ercc=factor(plot\$ercc, levels=as.vector(ord[,1]))
label=matrix(0,1,3) 
median=median(plot[, 3])
len=length(plot[, 3])
t=paste(\"\nMedian =\", prettyNum(round(median,2),big.mark=\",\",scientific=FALSE), \"%\")
label[1,1]=\"E\"
label[1,2]=\"All\"
label[1,3]=t
label=as.data.frame(label)
row.names(label)=NULL
colnames(label)=c('group', 'typ', 'text')
png(\"ercc.input.polyAtrimm.gc.png\", bg = \"white\", units=\"in\", width=12, height=6, res=300)
ggplot(plot, aes(x=ercc, y=count, fill=typ)) + geom_bar(stat=\"identity\", color=\"black\", width=0.8) + scale_fill_manual(values=cbPalette)+ ylim(0,60)+ xlab(\"\") + ylab (\"% GC\")+ theme_bw()+theme(axis.text.x = element_text(size = 10, colour = \"black\", angle=90, hjust=1, vjust=0.5), axis.text.y = element_text(size = 16,  colour = \"black\"), legend.text = element_text(size=14), plot.title = element_text(size = 22), legend.title =element_text(size=0, color=\"white\"), axis.title.x = element_text(size = 18), axis.title.y = element_text(size = 18), legend.text.align=0.5, strip.text.x=element_text(size=18), strip.text.y=element_text(size=18))+ ggtitle('')+theme(legend.position=\"none\")+facet_wrap(~typ)+ geom_text(data=label, aes(x=80, y=60, label=text), size=8, color=\"black\")
dev.off()
" | R --slave

cp ercc.input.polyAtrimm.gc.png /users/rg/buszczynska/public_html/gencode/tmp/B/COT/ercc

# per group
echo "
library(ggplot2)
library(scales)
plot <- read.table('ercc.input.polyAtrimm.gc.tsv', header=F, as.is=T, sep=\"\t\")
ord <- read.table('ercc.input.polyAtrimm.gc.order', header=F, as.is=T, sep=\"\t\")
colnames(plot)<-c(\"ercc\",\"group\",\"count\")
plot\$ercc=factor(plot\$ercc, levels=as.vector(ord[,1]))
list=c(\"A\",\"B\", \"C\", \"D\")
label=matrix(0,length(list),2) 
for (i in 1:length(list))
{
median=median(plot[plot\$group==list[i], 3])
len=length(plot[plot\$group==list[i], 3])
t=paste(\"\nMedian =\", prettyNum(round(median,2),big.mark=\",\",scientific=FALSE), \"%\")
label[i,1]=list[i]
label[i,2]=t
}

label=as.data.frame(label)
row.names(label)=NULL
colnames(label)=c('group', 'text')
png(\"ercc.input.polyAtrimm.gc.pergroup.png\", bg = \"white\", units=\"in\", width=16, height=8, res=300)
ggplot(plot, aes(x=ercc, y=count, fill=group)) + geom_bar(stat=\"identity\", color=\"black\") + scale_fill_brewer(palette=\"Dark2\")+ ylim(0,60)+ xlab(\"\") + ylab (\"% GC\")+ theme_bw()+theme(axis.text.x = element_text(size = 11, colour = \"black\", angle=90, hjust=1, vjust=0.5), axis.text.y = element_text(size = 16,  colour = \"black\"), legend.text = element_text(size=14), plot.title = element_text(size = 22), legend.title =element_text(size=0, color=\"white\"), axis.title.x = element_text(size = 18), axis.title.y = element_text(size = 18), legend.text.align=0.5, strip.text.x=element_text(size=18), strip.text.y=element_text(size=18))+ ggtitle('')+theme(legend.position=\"top\")+ geom_text(data=label[1,], aes(x=13, y=60, label=text), size=8, color=\"black\")+ geom_text(data=label[2,], aes(x=36, y=60, label=text), size=8, color=\"black\")+ geom_text(data=label[3,], aes(x=59, y=60, label=text), size=8, color=\"black\")+ geom_text(data=label[4,], aes(x=82, y=60, label=text), size=8, color=\"black\")
dev.off()
" | R --slave

cp ercc.input.polyAtrimm.gc.pergroup.png /users/rg/buszczynska/public_html/gencode/tmp/B/COT/ercc

# per group v2 with facet
echo "
library(ggplot2)
library(scales)
plot <- read.table('ercc.input.polyAtrimm.gc.tsv', header=F, as.is=T, sep=\"\t\")
ord <- read.table('ercc.input.polyAtrimm.gc.order', header=F, as.is=T, sep=\"\t\")
colnames(plot)<-c(\"ercc\",\"group\",\"count\")
plot\$ercc=factor(plot\$ercc, levels=as.vector(ord[,1]))
list=c(\"A\",\"B\", \"C\", \"D\")
label=matrix(0,length(list),2) 
for (i in 1:length(list))
{
median=median(plot[plot\$group==list[i], 3])
len=length(plot[plot\$group==list[i], 3])
t=paste(\"\nMedian =\", prettyNum(round(median,2),big.mark=\",\",scientific=FALSE), \"%\")
label[i,1]=list[i]
label[i,2]=t
}

label=as.data.frame(label)
row.names(label)=NULL
colnames(label)=c('group', 'text')
png(\"ercc.input.polyAtrimm.gc.pergroup.v2.png\", bg = \"white\", units=\"in\", width=12, height=8, res=300)
ggplot(plot, aes(x=ercc, y=count, fill=group)) + geom_bar(stat=\"identity\", color=\"black\") + scale_fill_brewer(palette=\"Dark2\")+ ylim(0,80)+ xlab(\"\") + ylab (\"% GC\")+ theme_bw()+theme(axis.text.x = element_text(size = 12, colour = \"black\", angle=90, hjust=1, vjust=0.5), axis.text.y = element_text(size = 16,  colour = \"black\"), legend.text = element_text(size=14), plot.title = element_text(size = 22), legend.title =element_text(size=0, color=\"white\"), axis.title.x = element_text(size = 18), axis.title.y = element_text(size = 18), legend.text.align=0.5, strip.text.x=element_text(size=18), strip.text.y=element_text(size=18))+ ggtitle('')+theme(legend.position=\"none\")+facet_wrap(~group, scales=\"free\")+ geom_text(data=label, aes(x=18, y=80, label=text), size=7, color=\"black\")
dev.off()
" | R --slave

cp ercc.input.polyAtrimm.gc.pergroup.v2.png /users/rg/buszczynska/public_html/gencode/tmp/B/COT/ercc

# -------------------------------------------------------
# size of polyA tail
# -------------------------------------------------------

while read ercc gr sequ
do
    len=`echo $sequ| wc -m`
    echo -e "$ercc\t$len\t$gr\tAll polyA tails"
done < ercc.input.polyAtrimm.tsv > ercc.length.polyAtrimm.tsv

# join
join.py -b ercc.length.tsv -a ercc.length.polyAtrimm.tsv -x 1 -y 1 | awk 'BEGIN{FS=OFS="\t"}{print $1, $2-$5, $3, $7}' > ercc.length.polyA.tsv


# All
echo "
library(ggplot2)
library(scales)
cbPalette <- c(\"#5b58c4\")
plot <- read.table('ercc.length.polyA.tsv', header=F, as.is=T, sep=\"\t\")
colnames(plot)<-c(\"ercc\",\"count\",\"group\", \"typ\")
label=matrix(0,1,3) 
median=median(plot[, 2])
len=length(plot[, 2])
t=paste(\"N =\", prettyNum(len,big.mark=\",\",scientific=FALSE), \"\nMedian =\", prettyNum(round(median,2),big.mark=\",\",scientific=FALSE))
label[1,1]=\"E\"
label[1,2]=\"All polyA tails\"
label[1,3]=t
label=as.data.frame(label)
row.names(label)=NULL
colnames(label)=c('group', 'typ', 'text')
png(\"ercc.length.polyA.png\", bg = \"white\", units=\"in\", width=6.5, height=6, res=300)
ggplot(plot, aes(x=count, color=typ)) + geom_density(size=2) + scale_color_manual(values=cbPalette)+ylim(0,0.3)+ xlim(20,35) + xlab(\"Length of polyA tails (nt)\") + ylab (\"Density\")+ theme_bw()+theme(axis.text.x = element_text(size = 16, colour = \"black\"), axis.text.y = element_text(size = 16,  colour = \"black\"), legend.text = element_text(size=14), plot.title = element_text(size = 22), legend.title =element_text(size=0, color=\"white\"), axis.title.x = element_text(size = 18), axis.title.y = element_text(size = 18), legend.text.align=0.5, strip.text.x=element_text(size=18), strip.text.y=element_text(size=18))+ ggtitle('')+theme(legend.position=\"none\")+facet_wrap(~typ)+ geom_text(data=label, aes(x=33, y=0.25, label=text), size=5, color=\"black\")
dev.off()
" | R --slave

cp ercc.length.polyA.png /users/rg/buszczynska/public_html/gencode/tmp/B/COT/ercc

# per group
echo "
library(ggplot2)
library(scales)
plot <- read.table('ercc.length.polyA.tsv', header=F, as.is=T, sep=\"\t\")
colnames(plot)<-c(\"ercc\",\"count\",\"group\", \"typ\")
list=c(\"A\",\"B\", \"C\", \"D\")
label=matrix(0,length(list),3) 
for (i in 1:length(list))
{
median=median(plot[plot\$group==list[i], 2])
len=length(plot[plot\$group==list[i], 2])
t=paste(\"N =\", prettyNum(len,big.mark=\",\",scientific=FALSE), \"\nMedian =\", prettyNum(round(median,2),big.mark=\",\",scientific=FALSE))
label[i,1]=list[i]
label[i,2]=\"All polyA tails\"
label[i,3]=t
}

label=as.data.frame(label)
row.names(label)=NULL
colnames(label)=c('group', 'typ', 'text')
png(\"ercc.length.polyA.pergr.png\", bg = \"white\", units=\"in\", width=8, height=6, res=300)
ggplot(plot, aes(x=count, color=group)) + geom_density(size=2) + scale_color_brewer(palette=\"Dark2\") +ylim(0,0.4)+ xlim(20,35)+ xlab(\"Length of polyA tails (nt)\") + ylab (\"Density\")+ theme_bw()+theme(axis.text.x = element_text(size = 16, colour = \"black\"), axis.text.y = element_text(size = 16,  colour = \"black\"), legend.text = element_text(size=14), plot.title = element_text(size = 22), legend.title =element_text(size=0, color=\"white\"), axis.title.x = element_text(size = 18), axis.title.y = element_text(size = 18), legend.text.align=0.5, strip.text.x=element_text(size=18), strip.text.y=element_text(size=18))+ ggtitle('')+theme(legend.position=\"none\")+facet_wrap(~group)+ geom_text(data=label, aes(x=33, y=0.35, label=text), size=5, color=\"black\")
dev.off()
" | R --slave

cp ercc.length.polyA.pergr.png /users/rg/buszczynska/public_html/gencode/tmp/B/COT/ercc

# -------------------------------------------------------
# concentration MIX1
# -------------------------------------------------------

cat ercc.metadata.tsv| grep -v Re-sort| awk 'BEGIN{FS=OFS="\t"}{print $2, $3, $4, "Concentration Mix1"}' > ercc.conc.mix1.tsv

# plot
echo "
library(ggplot2)
library(scales)
plot <- read.table('ercc.conc.mix1.tsv', header=F, as.is=T, sep=\"\t\")
ord <- read.table('ercc.input.polyAtrimm.gc.order', header=F, as.is=T, sep=\"\t\")
colnames(plot)<-c(\"ercc\",\"group\",\"count\", \"typ\")
plot\$ercc=factor(plot\$ercc, levels=as.vector(ord[,1]))
list=c(\"A\",\"B\", \"C\", \"D\")
label=matrix(0,length(list),3) 
for (i in 1:length(list))
{
median=median(plot[plot\$group==list[i], 3])
len=length(plot[plot\$group==list[i], 3])
t=paste(\"\nMedian =\", prettyNum(round(median,2),big.mark=\",\",scientific=FALSE), \"%\")
label[i,1]=list[i]
label[i,2]=\"Concentration Mix1\"
label[i,3]=t
}

label=as.data.frame(label)
row.names(label)=NULL
colnames(label)=c('group', 'text')
png(\"ercc.conc.mix1.pergroup.png\", bg = \"white\", units=\"in\", width=12, height=8, res=300)
ggplot(plot, aes(x=ercc, y=count, fill=group)) + geom_bar(stat=\"identity\", color=\"black\") + scale_fill_brewer(palette=\"Dark2\")+ xlab(\"\") + ylab (\"Concentration in Mix 1 (attomoles/ul)\")+ theme_bw()+theme(axis.text.x = element_text(size = 11, colour = \"black\", angle=90, hjust=1, vjust=0.5), axis.text.y = element_text(size = 16,  colour = \"black\"), legend.text = element_text(size=14), plot.title = element_text(size = 22), legend.title =element_text(size=0, color=\"white\"), axis.title.x = element_text(size = 18), axis.title.y = element_text(size = 18), legend.text.align=0.5, strip.text.x=element_text(size=18), strip.text.y=element_text(size=18))+ ggtitle('')+theme(legend.position=\"none\")+facet_wrap(~group, scales=\"free\")+ geom_text(data=plot, aes(x=ercc, y=count+200, label=round(count,2)), size=3.6, color=\"black\", angle=90, vjust=0.5, hjust=-0.3)
dev.off()
" | R --slave

cp ercc.conc.mix1.pergroup.png /users/rg/buszczynska/public_html/gencode/tmp/B/COT/ercc


# -------------------------------------------------------
# concentration MIX2
# -------------------------------------------------------

cat ercc.metadata.tsv| grep -v Re-sort| awk 'BEGIN{FS=OFS="\t"}{print $2, $3, $5, "Concentration Mix2"}' > ercc.conc.mix2.tsv

# plot
echo "
library(ggplot2)
library(scales)
plot <- read.table('ercc.conc.mix2.tsv', header=F, as.is=T, sep=\"\t\")
ord <- read.table('ercc.input.polyAtrimm.gc.order', header=F, as.is=T, sep=\"\t\")
colnames(plot)<-c(\"ercc\",\"group\",\"count\", \"typ\")
plot\$ercc=factor(plot\$ercc, levels=as.vector(ord[,1]))
list=c(\"A\",\"B\", \"C\", \"D\")
label=matrix(0,length(list),3) 
for (i in 1:length(list))
{
median=median(plot[plot\$group==list[i], 3])
len=length(plot[plot\$group==list[i], 3])
t=paste(\"\nMedian =\", prettyNum(round(median,2),big.mark=\",\",scientific=FALSE), \"%\")
label[i,1]=list[i]
label[i,2]=\"Concentration Mix1\"
label[i,3]=t
}

label=as.data.frame(label)
row.names(label)=NULL
colnames(label)=c('group', 'text')
png(\"ercc.conc.mix2.pergroup.png\", bg = \"white\", units=\"in\", width=12, height=8, res=300)
ggplot(plot, aes(x=ercc, y=count, fill=group)) + geom_bar(stat=\"identity\", color=\"black\") + scale_fill_brewer(palette=\"Dark2\")+ xlab(\"\") + ylab (\"Concentration in Mix 2 (attomoles/ul)\")+ theme_bw()+theme(axis.text.x = element_text(size = 11, colour = \"black\", angle=90, hjust=1, vjust=0.5), axis.text.y = element_text(size = 16,  colour = \"black\"), legend.text = element_text(size=14), plot.title = element_text(size = 22), legend.title =element_text(size=0, color=\"white\"), axis.title.x = element_text(size = 18), axis.title.y = element_text(size = 18), legend.text.align=0.5, strip.text.x=element_text(size=18), strip.text.y=element_text(size=18))+ ggtitle('')+theme(legend.position=\"none\")+facet_wrap(~group, scales=\"free\")+ geom_text(data=plot, aes(x=ercc, y=count+200, label=round(count,2)), size=3.6, color=\"black\", angle=90, vjust=0.5, hjust=-0.3)
dev.off()
" | R --slave

cp ercc.conc.mix2.pergroup.png /users/rg/buszczynska/public_html/gencode/tmp/B/COT/ercc


# -------------------------------------------------------
# Fold change
# -------------------------------------------------------

cat ercc.metadata.tsv| grep -v Re-sort| awk 'BEGIN{FS=OFS="\t"}{print $2, $3, $6, "Fold Change"}' > ercc.conc.fc.tsv

# plot
echo "
library(ggplot2)
library(scales)
plot <- read.table('ercc.conc.fc.tsv', header=F, as.is=T, sep=\"\t\")
ord <- read.table('ercc.input.polyAtrimm.gc.order', header=F, as.is=T, sep=\"\t\")
colnames(plot)<-c(\"ercc\",\"group\",\"count\", \"typ\")
plot\$ercc=factor(plot\$ercc, levels=as.vector(ord[,1]))
list=c(\"A\",\"B\", \"C\", \"D\")
label=matrix(0,length(list),3) 
for (i in 1:length(list))
{
median=median(plot[plot\$group==list[i], 3])
len=length(plot[plot\$group==list[i], 3])
t=paste(\"\nMedian =\", prettyNum(round(median,2),big.mark=\",\",scientific=FALSE), \"%\")
label[i,1]=list[i]
label[i,2]=\"Concentration Mix1\"
label[i,3]=t
}

label=as.data.frame(label)
row.names(label)=NULL
colnames(label)=c('group', 'text')
png(\"ercc.conc.fc.pergroup.png\", bg = \"white\", units=\"in\", width=12, height=8, res=300)
ggplot(plot, aes(x=ercc, y=count, fill=group))  + geom_point(shape=21, size=4) + scale_fill_brewer(palette=\"Dark2\")+ xlab(\"\") + ylab (\"Expected fold-change ratio (Mix1/Mix2)\")+ theme_bw()+theme(axis.text.x = element_text(size = 11, colour = \"black\", angle=90, hjust=1, vjust=0.5), axis.text.y = element_text(size = 16,  colour = \"black\"), legend.text = element_text(size=14), plot.title = element_text(size = 22), legend.title =element_text(size=0, color=\"white\"), axis.title.x = element_text(size = 18), axis.title.y = element_text(size = 18), legend.text.align=0.5, strip.text.x=element_text(size=18), strip.text.y=element_text(size=18))+ ggtitle('')+theme(legend.position=\"none\")+facet_wrap(~group, scales=\"free\")
dev.off()
" | R --slave

cp ercc.conc.fc.pergroup.png /users/rg/buszczynska/public_html/gencode/tmp/B/COT/ercc


# -------------------------------------------------------
# log2FC
# -------------------------------------------------------

cat ercc.metadata.tsv| grep -v Re-sort| awk 'BEGIN{FS=OFS="\t"}{print $2, $3, $7}' > ercc.conc.log2fc.tsv

# plot
echo "
library(ggplot2)
library(scales)
plot <- read.table('ercc.conc.log2fc.tsv', header=F, as.is=T, sep=\"\t\")
ord <- read.table('ercc.input.polyAtrimm.gc.order', header=F, as.is=T, sep=\"\t\")
colnames(plot)<-c(\"ercc\",\"group\",\"count\")
plot\$ercc=factor(plot\$ercc, levels=as.vector(ord[,1]))
list=c(\"A\",\"B\", \"C\", \"D\")
label=matrix(0,length(list),3) 
for (i in 1:length(list))
{
median=median(plot[plot\$group==list[i], 3])
len=length(plot[plot\$group==list[i], 3])
t=paste(\"\nMedian =\", prettyNum(round(median,2),big.mark=\",\",scientific=FALSE), \"%\")
label[i,1]=list[i]
label[i,2]=\"Concentration Mix1\"
label[i,3]=t
}

label=as.data.frame(label)
row.names(label)=NULL
colnames(label)=c('group', 'text')
png(\"ercc.conc.log2fc.pergroup.png\", bg = \"white\", units=\"in\", width=12, height=8, res=300)
ggplot(plot, aes(x=ercc, y=count, fill=group)) + geom_point(shape=21, size=4) + scale_fill_brewer(palette=\"Dark2\")+ xlab(\"\") + ylab (\"log2(Mix1/Mix2)\")+ theme_bw()+theme(axis.text.x = element_text(size = 11, colour = \"black\", angle=90, hjust=1, vjust=0.5), axis.text.y = element_text(size = 16,  colour = \"black\"), legend.text = element_text(size=14), plot.title = element_text(size = 22), legend.title =element_text(size=0, color=\"white\"), axis.title.x = element_text(size = 18), axis.title.y = element_text(size = 18), legend.text.align=0.5, strip.text.x=element_text(size=18), strip.text.y=element_text(size=18))+ ggtitle('')+theme(legend.position=\"none\")+facet_wrap(~group, scales=\"free\")
dev.off()
" | R --slave

cp ercc.conc.log2fc.pergroup.png /users/rg/buszczynska/public_html/gencode/tmp/B/COT/ercc

# -----------------------------------------------------------------------------
# Metatable with length, gc content, length of poly A tails, conc, etc
# -----------------------------------------------------------------------------

{ echo -e "ERCC_ID\tSubgroup\tLength\t%GC\tPolyA_tail_length\tConcentration_in_Mix1(attomoles/ul)\tconcentration_in_Mix2(attomoles/ul)\tExpected_fold-change_ratio\tlog2(Mix1/Mix2)" ; join.py -b ercc.length.tsv -a ercc.input.polyAtrimm.gc.tsv -x 1 -y 1 | join.py -b stdin -a ercc.length.polyA.tsv -x 1 -y 1| join.py -b stdin -a ercc.metadata.tsv -x 2 -y 1| awk 'BEGIN{FS=OFS="\t"}{print $1, $3, $2, $6, $7, $12, $13, $14, $15}' ; } > ercc.final.metatable.tsv

cp ercc.final.metatable.tsv /users/rg/buszczynska/public_html/gencode/tmp/B/COT/ercc

# -----------------------------------------------------------------------------
# Select the targets for taqman
# -----------------------------------------------------------------------------

# length - 990-1160 nts
# %GC - 46-53 
# poly(A) 21-29
# cont > 14

for typ in A B C D 
do
    cat ercc.final.metatable.tsv| grep -v ERCC_ID| awk -v t=$typ '$2==t'| awk '$3>=990 && $3<=1160'| awk '$4 >=46 && $4 <=53'| awk '$5 >= 21 && $5 <= 29'| awk 'BEGIN{FS=OFS="\t"}$6>=14 && $7>=14'
done > ercc.final.taqman.targets.tsv

cp ercc.final.taqman.targets.tsv /users/rg/buszczynska/public_html/gencode/tmp/B/COT/ercc

#cat ercc.final.metatable.tsv| grep -v ERCC_ID| awk '$2=="C"'| awk '$3>=990 && $3<=1160'| awk '$4 >=46 && $4 <=53'| awk '$5 >= 21 && $5 <= 29'| awk 'BEGIN{FS=OFS="\t"}$6>=14 && $7>=14'| head 


